==> doodle-reactor_3-0.21.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"reactor","t":"reactor","d":"","k":"static","x":""},
{"l":"doodle/reactor.html#","e":false,"i":"","n":"doodle.reactor","t":"doodle.reactor","d":"","k":"package","x":""},
{"l":"doodle/reactor/examples.html#","e":false,"i":"","n":"doodle.reactor.examples","t":"doodle.reactor.examples","d":"","k":"package","x":""},
{"l":"doodle/reactor/examples/Easing$.html#","e":false,"i":"","n":"Easing","t":"Easing","d":"doodle.reactor.examples","k":"object","x":""},
{"l":"doodle/reactor/examples/Easing$.html#easeIn-5b2","e":false,"i":"","n":"easeIn","t":"easeIn(t: Double): Double","d":"doodle.reactor.examples.Easing","k":"def","x":""},
{"l":"doodle/reactor/examples/Easing$.html#easeOut-5b2","e":false,"i":"","n":"easeOut","t":"easeOut(t: Double): Double","d":"doodle.reactor.examples.Easing","k":"def","x":""},
{"l":"doodle/reactor/examples/Easing$.html#go-94c","e":false,"i":"","n":"go","t":"go(): Unit","d":"doodle.reactor.examples.Easing","k":"def","x":""},
{"l":"doodle/reactor/examples/Easing$.html#reactor-0","e":false,"i":"","n":"reactor","t":"reactor: Reactor[Double]","d":"doodle.reactor.examples.Easing","k":"val","x":""},
{"l":"doodle/reactor/examples/Easing$.html#scale-49f","e":false,"i":"","n":"scale","t":"scale(min: Double, max: Double): Double => Double","d":"doodle.reactor.examples.Easing","k":"def","x":""},
{"l":"doodle/reactor/examples/Easing$.html#step-0","e":false,"i":"","n":"step","t":"step: Double => Double","d":"doodle.reactor.examples.Easing","k":"val","x":""},
{"l":"doodle/reactor/BaseReactor.html#","e":false,"i":"","n":"BaseReactor","t":"BaseReactor[A]","d":"doodle.reactor","k":"trait","x":""},
{"l":"doodle/reactor/BaseReactor.html#initial-0","e":false,"i":"","n":"initial","t":"initial: A","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#onMouseClick-f7c","e":false,"i":"","n":"onMouseClick","t":"onMouseClick(location: Point, state: A): A","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#onMouseMove-f7c","e":false,"i":"","n":"onMouseMove","t":"onMouseMove(location: Point, state: A): A","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#onTick-d26","e":false,"i":"","n":"onTick","t":"onTick(state: A): A","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#render-fffffc66","e":false,"i":"","n":"render","t":"render(value: A): Image","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#run-fffffb0c","e":false,"i":"","n":"run","t":"run[Alg <: Basic, Frame, Canvas](frame: Frame)(implicit a: AnimationRenderer[Canvas], e: Renderer[Alg, Frame, Canvas], m: MouseClick[Canvas] & MouseMove[Canvas], runtime: IORuntime): Unit","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#stop-4ad","e":false,"i":"","n":"stop","t":"stop(value: A): Boolean","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#tick-fffffbc3","e":false,"i":"","n":"tick","t":"tick[Frame, Canvas](frame: Frame)(implicit e: Renderer[Basic, Frame, Canvas], runtime: IORuntime): Option[A]","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#tickRate-0","e":false,"i":"","n":"tickRate","t":"tickRate: FiniteDuration","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor$.html#","e":false,"i":"","n":"BaseReactor","t":"BaseReactor","d":"doodle.reactor","k":"object","x":""},
{"l":"doodle/reactor/BaseReactor$$Command.html#","e":false,"i":"","n":"Command","t":"Command extends Product, Serializable","d":"doodle.reactor.BaseReactor","k":"class","x":""},
{"l":"doodle/reactor/BaseReactor$$MouseClick.html#","e":false,"i":"","n":"MouseClick","t":"MouseClick(location: Point) extends Command","d":"doodle.reactor.BaseReactor","k":"class","x":""},
{"l":"doodle/reactor/BaseReactor$$MouseMove.html#","e":false,"i":"","n":"MouseMove","t":"MouseMove(location: Point) extends Command","d":"doodle.reactor.BaseReactor","k":"class","x":""},
{"l":"doodle/reactor/BaseReactor$$Tick$.html#","e":false,"i":"","n":"Tick","t":"Tick extends Command","d":"doodle.reactor.BaseReactor","k":"object","x":""},
{"l":"doodle/reactor/Reactor.html#","e":false,"i":"","n":"Reactor","t":"Reactor[A](initial: A, onMouseClickHandler: (Point, A) => A, onMouseMoveHandler: (Point, A) => A, onTickHandler: A => A, tickRate: FiniteDuration, renderHandler: A => Image, stopHandler: A => Boolean) extends BaseReactor[A]","d":"doodle.reactor","k":"class","x":""},
{"l":"doodle/reactor/Reactor.html#draw-6d3","e":false,"i":"","n":"draw","t":"draw[Alg <: Basic, Frame, Canvas](frame: Frame)(implicit renderer: Renderer[Alg, Frame, Canvas], runtime: IORuntime): Unit","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#draw-fffff88b","e":false,"i":"","n":"draw","t":"draw[Alg <: Basic, Frame, Canvas]()(implicit renderer: DefaultRenderer[Alg, Frame, Canvas], runtime: IORuntime): Unit","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#image-0","e":false,"i":"","n":"image","t":"image: Image","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#onMouseClick-f7c","e":false,"i":"","n":"onMouseClick","t":"onMouseClick(location: Point, state: A): A","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#onMouseMove-f7c","e":false,"i":"","n":"onMouseMove","t":"onMouseMove(location: Point, state: A): A","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#onTick-d26","e":false,"i":"","n":"onTick","t":"onTick(state: A): A","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#render-fffffc66","e":false,"i":"","n":"render","t":"render(value: A): Image","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#step-0","e":false,"i":"","n":"step","t":"step: Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#stop-4ad","e":false,"i":"","n":"stop","t":"stop(value: A): Boolean","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#withOnMouseClick-fffffd73","e":false,"i":"","n":"withOnMouseClick","t":"withOnMouseClick(f: (Point, A) => A): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#withOnMouseMove-fffffd73","e":false,"i":"","n":"withOnMouseMove","t":"withOnMouseMove(f: (Point, A) => A): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#withOnTick-432","e":false,"i":"","n":"withOnTick","t":"withOnTick(f: A => A): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#withRender-432","e":false,"i":"","n":"withRender","t":"withRender(f: A => Image): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#withStop-432","e":false,"i":"","n":"withStop","t":"withStop(f: A => Boolean): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#withTickRate-fffff16f","e":false,"i":"","n":"withTickRate","t":"withTickRate(duration: FiniteDuration): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor$.html#","e":false,"i":"","n":"Reactor","t":"Reactor","d":"doodle.reactor","k":"object","x":""},
{"l":"doodle/reactor/Reactor$.html#init-ffffff25","e":false,"i":"","n":"init","t":"init[A](value: A): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor$.html#linearRamp-c6c","e":false,"i":"","n":"linearRamp","t":"linearRamp(start: Double, stop: Double, step: Double): Reactor[Double]","d":"doodle.reactor.Reactor","k":"def","x":""}];

==> doodle-reactor_3-0.23.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"reactor","t":"reactor","d":"","k":"static","x":""},
{"l":"doodle/reactor.html#","e":false,"i":"","n":"doodle.reactor","t":"doodle.reactor","d":"","k":"package","x":""},
{"l":"doodle/reactor/examples.html#","e":false,"i":"","n":"doodle.reactor.examples","t":"doodle.reactor.examples","d":"","k":"package","x":""},
{"l":"doodle/reactor/examples/Easing$.html#","e":false,"i":"","n":"Easing","t":"Easing","d":"doodle.reactor.examples","k":"object","x":""},
{"l":"doodle/reactor/examples/Easing$.html#easeIn-5b2","e":false,"i":"","n":"easeIn","t":"easeIn(t: Double): Double","d":"doodle.reactor.examples.Easing","k":"def","x":""},
{"l":"doodle/reactor/examples/Easing$.html#easeOut-5b2","e":false,"i":"","n":"easeOut","t":"easeOut(t: Double): Double","d":"doodle.reactor.examples.Easing","k":"def","x":""},
{"l":"doodle/reactor/examples/Easing$.html#go-94c","e":false,"i":"","n":"go","t":"go(): Unit","d":"doodle.reactor.examples.Easing","k":"def","x":""},
{"l":"doodle/reactor/examples/Easing$.html#reactor-0","e":false,"i":"","n":"reactor","t":"reactor: Reactor[Double]","d":"doodle.reactor.examples.Easing","k":"val","x":""},
{"l":"doodle/reactor/examples/Easing$.html#scale-49f","e":false,"i":"","n":"scale","t":"scale(min: Double, max: Double): Double => Double","d":"doodle.reactor.examples.Easing","k":"def","x":""},
{"l":"doodle/reactor/examples/Easing$.html#step-0","e":false,"i":"","n":"step","t":"step: Double => Double","d":"doodle.reactor.examples.Easing","k":"val","x":""},
{"l":"doodle/reactor/BaseReactor.html#","e":false,"i":"","n":"BaseReactor","t":"BaseReactor[A]","d":"doodle.reactor","k":"trait","x":""},
{"l":"doodle/reactor/BaseReactor.html#initial-0","e":false,"i":"","n":"initial","t":"initial: A","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#onMouseClick-f7c","e":false,"i":"","n":"onMouseClick","t":"onMouseClick(location: Point, state: A): A","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#onMouseMove-f7c","e":false,"i":"","n":"onMouseMove","t":"onMouseMove(location: Point, state: A): A","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#onTick-d26","e":false,"i":"","n":"onTick","t":"onTick(state: A): A","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#render-fffffc66","e":false,"i":"","n":"render","t":"render(value: A): Image","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#run-fffffb0c","e":false,"i":"","n":"run","t":"run[Alg <: Basic, Frame, Canvas](frame: Frame)(implicit a: AnimationRenderer[Canvas], e: Renderer[Alg, Frame, Canvas], m: MouseClick[Canvas] & MouseMove[Canvas], runtime: IORuntime): Unit","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#stop-4ad","e":false,"i":"","n":"stop","t":"stop(value: A): Boolean","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#tick-fffffbc3","e":false,"i":"","n":"tick","t":"tick[Frame, Canvas](frame: Frame)(implicit e: Renderer[Basic, Frame, Canvas], runtime: IORuntime): Option[A]","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor.html#tickRate-0","e":false,"i":"","n":"tickRate","t":"tickRate: FiniteDuration","d":"doodle.reactor.BaseReactor","k":"def","x":""},
{"l":"doodle/reactor/BaseReactor$.html#","e":false,"i":"","n":"BaseReactor","t":"BaseReactor","d":"doodle.reactor","k":"object","x":""},
{"l":"doodle/reactor/BaseReactor$$Command.html#","e":false,"i":"","n":"Command","t":"Command extends Product, Serializable","d":"doodle.reactor.BaseReactor","k":"class","x":""},
{"l":"doodle/reactor/BaseReactor$$MouseClick.html#","e":false,"i":"","n":"MouseClick","t":"MouseClick(location: Point) extends Command","d":"doodle.reactor.BaseReactor","k":"class","x":""},
{"l":"doodle/reactor/BaseReactor$$MouseMove.html#","e":false,"i":"","n":"MouseMove","t":"MouseMove(location: Point) extends Command","d":"doodle.reactor.BaseReactor","k":"class","x":""},
{"l":"doodle/reactor/BaseReactor$$Tick$.html#","e":false,"i":"","n":"Tick","t":"Tick extends Command","d":"doodle.reactor.BaseReactor","k":"object","x":""},
{"l":"doodle/reactor/Reactor.html#","e":false,"i":"","n":"Reactor","t":"Reactor[A](initial: A, onMouseClickHandler: (Point, A) => A, onMouseMoveHandler: (Point, A) => A, onTickHandler: A => A, tickRate: FiniteDuration, renderHandler: A => Image, stopHandler: A => Boolean) extends BaseReactor[A]","d":"doodle.reactor","k":"class","x":""},
{"l":"doodle/reactor/Reactor.html#draw-6d3","e":false,"i":"","n":"draw","t":"draw[Alg <: Basic, Frame, Canvas](frame: Frame)(implicit renderer: Renderer[Alg, Frame, Canvas], runtime: IORuntime): Unit","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#draw-fffff5f4","e":false,"i":"","n":"draw","t":"draw[Alg <: Basic, Frame, Canvas]()(implicit renderer: Renderer[Alg, Frame, Canvas], frame: DefaultFrame[Frame], runtime: IORuntime): Unit","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#image-0","e":false,"i":"","n":"image","t":"image: Image","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#onMouseClick-f7c","e":false,"i":"","n":"onMouseClick","t":"onMouseClick(location: Point, state: A): A","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#onMouseMove-f7c","e":false,"i":"","n":"onMouseMove","t":"onMouseMove(location: Point, state: A): A","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#onTick-d26","e":false,"i":"","n":"onTick","t":"onTick(state: A): A","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#render-fffffc66","e":false,"i":"","n":"render","t":"render(value: A): Image","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#step-0","e":false,"i":"","n":"step","t":"step: Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#stop-4ad","e":false,"i":"","n":"stop","t":"stop(value: A): Boolean","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#withOnMouseClick-fffffd73","e":false,"i":"","n":"withOnMouseClick","t":"withOnMouseClick(f: (Point, A) => A): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#withOnMouseMove-fffffd73","e":false,"i":"","n":"withOnMouseMove","t":"withOnMouseMove(f: (Point, A) => A): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#withOnTick-432","e":false,"i":"","n":"withOnTick","t":"withOnTick(f: A => A): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#withRender-432","e":false,"i":"","n":"withRender","t":"withRender(f: A => Image): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#withStop-432","e":false,"i":"","n":"withStop","t":"withStop(f: A => Boolean): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor.html#withTickRate-fffff16f","e":false,"i":"","n":"withTickRate","t":"withTickRate(duration: FiniteDuration): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor$.html#","e":false,"i":"","n":"Reactor","t":"Reactor","d":"doodle.reactor","k":"object","x":""},
{"l":"doodle/reactor/Reactor$.html#init-ffffff25","e":false,"i":"","n":"init","t":"init[A](value: A): Reactor[A]","d":"doodle.reactor.Reactor","k":"def","x":""},
{"l":"doodle/reactor/Reactor$.html#linearRamp-c6c","e":false,"i":"","n":"linearRamp","t":"linearRamp(start: Double, stop: Double, step: Double): Reactor[Double]","d":"doodle.reactor.Reactor","k":"def","x":""}];
